# 1. State of the art, project management and documentation

## Objectives

* Learn the process and tools used to document course work
* Acquire the necessary skills to publish projects, documentation and share the results of each assignment

## Student checklist
* Build a documentation website describing you and your motivation for the textile-academy, including your previous work
* Upload the documentation to your project page on class.textile-academy.org
* Add references and research based on the topic of your interest
* Learn how to upload images, videos, references and how to use Markdown and Gitlab
* Learn about the fab lab processes, booking system, usage, machine demos, tools and safety rules
* Customize your website and document how you did it (extra credit)

## Some Inspirations

[Special Projects Studio](https://specialprojects.studio/)
<p align="center"><img alt="13" src="../../images/week01/13.png" /></p>

[Automatic Machine Knitting of 3D Meshes](https://textiles-lab.github.io/publications/2018-autoknit/)
<p align="center"><img alt="14" src="../../images/week01/14.png" /></p>

[Amanda Ghassaei](https://amandaghassaei.com/)
<p align="center"><img alt="15" src="../../images/week01/15.png" /></p>

[Nervous System](https://n-e-r-v-o-u-s.com/index.php)
<p align="center"><img alt="16" src="../../images/week01/16.png" /></p>

[Artistic toys by Blight Design](http://blightdesign.com/robot_copyright.html)
<p align="center"><img alt="17" src="../../images/week01/17.png" /></p>

[Sensory Maps](https://sensorymaps.com/)
<p align="center"><img alt="18" src="../../images/week01/18.png" /></p>

A brief introduction about me and my work is [here](https://class.textile-academy.org/2022/nanditha-nair/about/about/)

## Research
* [Material for MKDocs - Documentation](https://squidfunk.github.io/mkdocs-material/)
* [p5.js](https://p5js.org/)
 
### Building the website
I was already familiar with Git, Git lab and creating webpages using gitlab. The material theme of MK docs which runs on markdown is also something I'm used to doing ever since Fabacademy. 
#### Jekyll vs MK Docs Material
My primary dilemma was whether to change the given template of material for MKDocs. I thought of using a [Jekyll theme](http://jekyllthemes.org/) but after a short chat with Cecilia on Mattermost I reassessed my options and decided to focus my efforts on content rather than the theme. 
#### Weaving Creative using P5.js
I wanted to learn something new and decided on using my time to learn [p5.js](https://p5js.org/) to create a cover for the website that can show the movement of the loom. I want it to be an experiment for the user to change the colours and weaves in real time giving the person a feel of weaving a piece of clothing. It should be a piece connecting the weaving and coding with the of notion of sentience. 
<br>I have worked on processing before and started learning p5.js through [Daniel Shiffman's tutorials on YouTube](https://www.youtube.com/watch?v=8j0UDiN7my4&t=55s). 
### Customising the theme
I want the front page to be clear of content to later add the loom creative, so I created a separate “About” menu on top and added pages under it. For this I created a subdirectory called About under Docs in my git project and added 2 new files called about.md and theme.md. This created 2 new pages-about and theme under the menu about. I added an image on the front page as a placeholder. 
<p align="center"><img alt="about git" src="../../images/week01/1.jpg" /></p>
I deleted the content on index.md and added a placeholder image of a loom that I added to the images subdirectory under docs.
<p align="center"><img alt="about page" src="../../images/week01/2.jpg" /></p>
I also deleted all the content on the index page.
<p align="center"><img alt="about page" src="../../images/week01/3.jpg" /></p>
Next I changed the header to white by changing the primary colour as white in the mkdocs.yml file.
<p align="center"><img alt="white" src="../../images/week01/4.jpg" /></p>
I also changed the text font to Ubuntu from Roboto. After checking the MKDocs documentation I decided to add the navigation tabs so it is possible to view the top level sections as rendered under the menu tab.
<p align="center"><img alt="white" src="../../images/week01/5.jpg" /></p>
I also changed the site_name, site_description and site_author in mkdocs.yml.
<p align="center"><img alt="white" src="../../images/week01/6.jpg" /></p>
Here the change is evident:
<p align="center"><img alt="white" src="../../images/week01/7.jpg" /></p>
I also changed the favicon by replacing it with another image of yarn in the yellow background. 
<p align="center"><img alt="white" src="../../images/week01/8.jpg" /></p>
The yellow yarn favicon is popping up against other website icons.
<p align="center"><img alt="white" src="../../images/week01/9.jpg" /></p>
Now I started to document it by changing the content in about.md

I again changed all the colours and the nav icon to reflect my theme as given in the page [colour palette](https://class.textile-academy.org/2022/nanditha-nair/about/theme/).

#### Changing the header line 

I wanted to change the colour of the line under the header, so added the following code to extra.css

```jsx
.header {
  background-color: [#ffffff];
  border-bottom: 3px solid [#BE9852];
  }
```

But there was no change. 

Then I figured out there is no class named header and it is `md-header`instead  (ie from `<header class="md-header">`). I renamed the css class to `.md-header` and it worked.

```jsx
.md-header {
  background-color: [#ffffff];
  border-bottom: 3px solid [#BE9852];
  }
```
<p align="center"><img alt="white" src="../../images/week01/10.png" /></p>

It worked. But I was wrong in assuming the black line was underneath the header. It is under menu navigation bar.

I tried this but did not work

```jsx
md-tabs {
  border-bottom: 3px solid [#BE9852];
}
```

Then I tried this but this also did not work

```
@media screen and (min-width: 76.25em) {
    [data-md-color-primary="white"] .md-tabs {
        border-bottom: .05rem solid rgba(0,0,0,.07);
   }
}
```

Then Julian Gallimore helped and explained to me the mistake I made, ie the order was wrong. 

Because of the way CSS works, order matters! So my `.md-tabs`  line is lower in the list that the above code, in CSS eyes.

This screenshot shows that the custom CSS is put below the "themes" border bottom and it needs to be changed.
<p align="center"><img alt="white" src="../../images/week01/11.png" /></p> 
The order was changed and the golden line is ready.
<p align="center"><img alt="white" src="../../images/week01/12.png" /></p>

