# 5. E-textiles

## Objectives

- References and Concept development
- Understand how we can produce soft circuits, sensors and actuators
- Learn how to embed electronics on fabrics
- Study and learn soft-hard connections
- Discover necessary materials, components, tools
- Explore and replicate existing projects

## Checklist

- Build at least one digital and one analogue soft sensor, using different materials and techniques.
- Document the sensor project as well as the readings got using the AnalogRead of Arduino
- Integrate the two soft sensors into one or two textile swatches using hard soft connections
- Document the circuit and its schematic
- Document your swatches / samples
- Upload your arduino code as text
- Upload a small video of the swatches functioning
- Integrate the swatch into a project (extra credit)

<center><iframe src="https://player.vimeo.com/video/217391196?h=74dd327484" width="640" height="360" frameborder="0" allow="autoplay; fullscreen; picture-in-picture" allowfullscreen></iframe></center>
<p><center><a href="https://vimeo.com/217391196">Ambient Play</a> from <a href="https://vimeo.com/theurbanconga">THE URBAN CONGA</a> on <a href="https://vimeo.com">Vimeo</a></center></p>

<center><iframe width="560" height="315" src="https://www.youtube.com/embed/vTBp0Z5GPeI" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

## Setting up Arduino
<p align="center"><img alt="1" src="../../images/week05/1.png" /></p>


## Digital Sensor

Any electronic sensor in which the output gives an OPEN or CLOSE state. 
A switch is a digital sensor that gives an Off(open) or On(close) output. The clasp of a necklace, a safety pin Open open or closed etc can be used as a switch.

### Improvising with available materials
I decided to make a collar to demonstrate digital sensor. I made some connections from Barcelona and planned to do the rest back home. I only had 3 months(Nov 22-Dec 22, Feb 1-March 30) for completing all assignments and project. I had some assignemnets pending when got back to India. I brought some conductive thread to do the project as it is not available at home but it was confiscated(among some other things from my electronics kit) by the officers in New Delhi Airport. Although there was no problem at Barcelona and Abu Dhabi airports. Indian airport security is very stringent. So I had to improvise and decided to find out what all I have/ can get and use it for E-textiles and Wearables.

<br>Testing some copper tape and LED. 
<center><iframe width="640" height="564" src="https://player.vimeo.com/video/826447700?h=41fd654f4a" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

Tried to connect the LEDs serially. 
<center><iframe width="640" height="564" src="https://player.vimeo.com/video/826448064?h=c2663383c0" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

<p align="center"><img alt="5" src="../../images/week05/5.jpg" /></p>

<br>Using the multimeter I checked for connections. It seems good to go.

<center><iframe width="640" height="564" src="https://player.vimeo.com/video/826448457?h=2b49d43d7c" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

### Safety Pin as a Digital Sensor
Instead of a switch I used a safety pin, the battery was connected to the thread with a copper wire. It was not 100% good but workable. 

<center><iframe width="640" height="564" src="https://player.vimeo.com/video/826448509?h=4c17de7054" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

### Cat Collar

I put the collar on Manjan when he was asleep. Here he is half awake and looking pawsome like always!

<center><iframe width="640" height="564" src="https://player.vimeo.com/video/826449419?h=fd7e832d91" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>


## Analog Sensor

The analog sensors give a continuous output signal proportional to the measurement.

### Eontex Fabric
An Eontex fabric is a conductive, nonwoven microfiber for use in e-textiles. These conductive fabrics are created by coding a fabric substrate in a durable and lightweight conductive polymer. NW 170 SLPA is a non woven conductive material with piezo resistive properties this means that as you press on it the resistance the material changes this makes it great for things like soft pressure sensors.
<p align="center"><img alt="14" src="../../images/week05/14.jpg" /></p>

<center><iframe width="640" height="564" src="https://player.vimeo.com/video/826449909?h=9207e5fd82" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

### To find the resistance between a voltage divider circuit

Voltage dividers can be used to allow a microcontroller to measure the resistance of a sensor. The sensor is wired in series with a known resistance to form a voltage divider and a known voltage is applied across the divider. 

<p align="center"><img alt="14" src="../../images/week05/15.jpg" /></p>


<center><iframe width="640" height="564" src="https://www.youtube.com/embed/Aywb_Rfzoxs" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

```jsx
void setup() {
  // put your setup code here, to run once:
  pinMode(A0,INPUT);
  pinMode(12,OUTPUT);
  Serial.begin(9600);
  

}

void loop() {
  // put your main code here, to run repeatedly:
  if(analogRead(A0) > 2000){
    digitalWrite(12, HIGH);
  }
  else{
    digitalWrite(12,LOW);
  }
  Serial.println(analogRead(A0));
  delay(100);

}
```
<center><iframe width="640" height="564" src="https://www.youtube.com/embed/rAByj7U2bBk" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

```jsx
#include <analogWrite.h>
void setup() {
  // put your setup code here, to run once:
  pinMode(A0,INPUT);
  pinMode(12,OUTPUT);
  Serial.begin(9600);
  

}
void loop() {
  // put your main code here, to run repeatedly:
  int value = analogRead(A0);
  Serial.println(value);
  int mappedValue = map(value, 600, 4095, 0, 255);
  Serial.println(mappedValue);
  int consValue = constrain(mappedValue, 0, 255);
  Serial.println(consValue);
  analogWrite(12, consValue);
  delay(100);

}
```

