# 8. Wearables

## Learning outcomes

- References and Concept development
- Design: program a microcontroller, design circuit and schematic
- Fabrication: Integrate inputs and outputs in a microcontroller wearable project
- Documentation: Anyone can go through the process, understand it and reproduce it
- Final outcome: Assembled project, functioning and complete
- Originality - Aesthetics: Has the design been thought through and elaborated?

## Student checklist

- Document the concept, sketches, references also to artistic and scientific publications
- Create a swatch/sample using an ATTiny/Arduino/Adafruit with one input and one output, using hard-soft connection solutions and battery
- Create 2 actuator swatches and test them with the Arduino or ATTiny, chosing from examples such as: motors / mini vibration, leds / neopixels, flip dot / electromagnet, heat pad / with thermochromic coating, speaker / mp3 player, SMA (shape memory alloy)
- Learn how to program an Arduino/ATTiny/Adrafruit, documenting your process, the libraries added, power requirements and source code
- Document the schematic and circuit
- Upload a small video of your object working
- Integrate it to a project (extra credit)
Initially my idea was to detect the temperature of the dog/cat using temperature sensor LM35 and show it on the collar. Then I decided to use an LDR sensor that detects the presence or absence of light. I decided to use an LDR sensor and make a dog collar. The dog collar will have LEDs across it and and an LDR sensor. When there is low light, the LEDs should light up and when the light is high, LEDs won't light up. 

## Cat collar with LDR Sensor

I want to build a cat collar that has a lilypad and battery sewn into it. But with supplies being limited I decided to make use of the collar from etextiles week to make the collar with sensor. 

### What is an LDR Sensor?
<center><iframe width="560" height="315" src="https://www.youtube.com/embed/2fvXW4OEWLE" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

** Spiralling my way into the week**

** 1.Make an LED light up when connected to battery**

<center><iframe width="560" height="315" src="https://www.youtube.com/embed/Rwj3rxksJ28" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>
<br>
** 2.Make an LED light up when it is dark with an LDR sensor**
[How to make a Dark Sensor](https://www.instructables.com/How-to-Make-a-Dark-Sensor-3/)
This video shows how to set up Arduino and connect an LED to light up:
<center><iframe width="560" height="315" src="https://www.youtube.com/embed/fJWR7dBuc18" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>
<br>
Finding how the resistance changes in an LDR sensor
<center><iframe width="640" height="564" src="https://player.vimeo.com/video/826409639?h=6b7de8c694" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

Next I connected an LDR with a resistor to read the input light values
<p align="center"><img alt="1" src="../../images/week05/1.jpg" /></p>
<p align="center"><img alt="2" src="../../images/week05/2.png" /></p>
<p align="center"><img alt="3" src="../../images/week05/3.png" /></p>
I test programmed an LED to show RGB values.
<p align="center"><img alt="5" src="../../images/week05/5.png" /></p>
<p align="center"><img alt="4" src="../../images/week05/4.png" /></p>
<p align="center"><img alt="2" src="../../images/week05/2.jpg" /></p>

I wrote a program to light up the builtin LED of the Arduino when there is low light.
<center><iframe width="640" height="564" src="https://player.vimeo.com/video/826410286?h=cb1ce77b9a" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

```jsx
int ldrPin=A0;
int ldrVal=0;
int ledPin=LED_BUILTIN;
void setup() {
  // put your setup code here, to run once:
Serial.begin(9600);
pinMode(ledPin,OUTPUT);
}

void loop() {
    // put your main code here, to run repeatedly:
ldrVal= analogRead(ldrPin); //0-1023
Serial.println(ldrVal);
if(ldrValint ldrVal=0;)
{
  digitalWrite(ledPin,HIGH);
  Serial.println("on");
}
else
{
  digitalWrite(ledPin,LOW);
  Serial.println("off");
}
delay(100);
}
```

Next I connected an external LED and a 220 ohm resistor to Pin 7. 
<p align="center"><img alt="9" src="../../images/week08/9.jpg" /></p>
For switching on the external LED when there is low light, I used the same code but changed the LED_BUILTIN(in line 3) with the pin to which the LED is connected, ie Pin 7.

```jsx
int ledPin=7;

```
<center><iframe width="640" height="564" src="https://player.vimeo.com/video/826410323?h=f4a240defd" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

After this I used the same cat collar I made in week 5 and connected it with the circuit.
<center><iframe width="640" height="564" src="https://player.vimeo.com/video/826410364?h=6316a42072" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>

As I didn't have much supplies I had to refurbish everything. I ripped some embroidery threads that I was planning to make Speaker with. I used a strand of the thread for connctions.
<p align="center"><img alt="5" src="../../images/week08/5.jpg" /></p>

## Preparing Actuators:MOSFET circuits

To create a circuit using an N-Channel MOSFET transistor, follow these steps:

Materials needed:

Copper tape
Regular tape
N-Channel MOSFET transistor
Soldering iron and solder
Pliers
9V battery clip
1N4007 diode (optional, for safety)
Steps:

Apply the copper tape in the pattern shown below, ensuring that the traces are aligned correctly. Use regular tape to insulate the middle and left MOSFET traces from each other. This will prevent them from making contact.

<p align="center"><img alt="MOSFET_symbol" src="../../images/week08/MOSFET_symbol.png" /></p>
Carefully use the pliers to bend the legs of the MOSFET. Make sure they are far enough apart from each other so that the copper traces won't touch. Also, ensure that the MOSFET lies flat on the paper.

Solder the legs of the MOSFET and the 9V battery clip to the respective copper tape traces. Double-check the connections to ensure they are secure.

If you want to add an extra layer of safety, you can include a 1N4007 diode. Connect the diode in parallel with the load (e.g., motor or heating pad) for better protection.
<p align="center"><img alt="6" src="../../images/week08/6.jpg" /></p>
By following these steps, you will have successfully set up an N-Channel MOSFET circuit that can control the power flow to a high-power actuator using an IC or microcontroller. This arrangement allows you to power the IC at a lower voltage while using its control signals to manage the flow of higher power from a separate secondary power source to the actuator. It's a useful way to control devices that require different operating voltages within a single control circuit.
<p align="center"><img alt="7" src="../../images/week08/7.jpg" /></p>
I wound some zardosi embroidery thread like a coil and placed a 10mm magnet from an old bag project of mine in the middle. This should create an electromagnet.
<p align="center"><img alt="8" src="../../images/week08/8.jpg" /></p>
Here I tested it's working. 
<center> <iframe width="640" height="564" src="https://www.youtube.com/embed/vXG89ZV9VZg" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe></center>
However the elctromagnet did not work I think due to the low external power, it requires 9v, I connected 3 3v batteries but one of them has very low power and might be the reaon it did not flutter. I have to fix the external power.

## Bill of Materials 
| Qty |  Description    |  Price  |           Link           |
|-----|-----------------|---------|--------------------------|
| 1   | Arduino Uno   | |Lab inventory   |
| 1   | Resistor 220 ohm |  | Lab inventory   |
| 1   | Resistor 1 kohm   |  | Lab inventory     |
| 1 set   | Jumper wires   |  | Lab inventory    |
| 1   | LDR resistor  |  | Lab inventory    |
| 1   |9v Battery  |  | Lab inventory    |
| 1   | IRF230 mosfet  |  | Lab inventory    |
| 1   | IN4001 Diode |  | Lab inventory    |
| 2   | neodymium magnet 10mm |  | Lab inventory    |
| 1   | Coil |  | Lab inventory    |
| 1   | Thick paper/card |  | Lab inventory    |
| 1   | Copper Tape |  | Lab inventory    |

## Files
Files can be downloaded from [here](https://gitlab.fabcloud.org/academany/fabricademy/2022/students/nanditha-nair/-/tree/main/docs/files/week08)
