# 10. Open Source Hardware - From Fibers to Fabric

## Learning outcomes

- References and Concept development
- Design: sketch, 3D modeling, electronics
- Fabrication: Capable of executing from file to production workflow, from 3D modelling to digital fabrication, electronics, materials
- Documentation: Anyone can go through the process, understand it and reproduce it
- Final outcome: Is the project assembled, functioning and complete
- Originality - Aesthetics: Has the design been thought through and elaborated?

## Student checklist

- Research and document existing fabrication methods, machines and industries, add references, tutorials and sketches of the hardware you will make
- Document the process of designing the files for your machine/machine-hack/tool and its fabrication including the assembly process
- Document the schematic and the software source code (if any)
- Document the parts and how to make your tool or machine
- Document your BOM (Bill of materials): electronics, materials, their amount, etcetera (with references of the components)
- Upload your 3D model and CAM files (if any)
- Design, create and document a final outcome, a sample project of your process
- Make a small video of the machine
- Create an interface for controlling your machine (extra credit)

## Concept Development

I self-learned about textiles and handicrafts and worked along with the weavers in various handloom clusters in India. There was a conscious effort from my part to better the lives of the artisans through design intervention and market intervention. One of the challenges I faced in learning about the craft was the lack of prototyping looms in India. I learned Computer Aided Designing and Digital Fabrication in 2020 through Fabacademy at Superfablab, Kerala. I was inspired by the concept of Distributed Design and decided to use my skill sets for the digitalization of weaving.

### The state of handloom

The hereditary nature of knowledge transfer that allows families and communities to take up art and craft in India is sounding the death knell of this sector. Traditional practitioners typically do not want their children to take up this profession as the financial and social benefits associated are almost negligible in the current economic scenario. The professionals who are interested in exploring the possibilities of weaving are intimidated by the long learning curve and the relatively low design flexibility. These challenges call for a systemic change in terms of technology update that allows weaving to become a new-age skill that got democratised due to technological changes, like photography or graphic design. The latest invention in handloom is the Jacquard loom (1801) which consists of a set of interchangeable punch cards depending on the pattern to be generated. These cards bore either a hole or flat surface to raise or lower warp threads. This paved the way for the origin of computers as programming languages are made of 0s and 1s. A set of metal Jacquard plates needs to be designed and fabricated for every design required. Its making and installation are a time-consuming process. Also, control over every yarn is not easily possible. The prototyping table looms available in India are very costly, and are mostly imported from the United States of America. The first objective of this project was to make a foldable table loom that makes learning the techniques of weaving easier.
<!-- Slider main container -->
<div class="swiper">
<!-- Additional required wrapper -->
<div class="swiper-wrapper">
    <!-- Slides -->
     <div class="swiper-slide">
        <center><img src="../../images/week10/1.jpg" alt="1"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/2.jpg" alt="2"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/3.jpg" alt="3"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/4.jpg" alt="4"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/5.jpg" alt="5"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/6.jpg" alt="6"></center>
    </div>
    <div class="swiper-slide">
        <center><img src="../../images/week10/7.jpg" alt="7"></center>
    </div>
  </div>  
<div class="swiper-pagination"></div>
<div class="swiper-button-prev"></div>
<div class="swiper-button-next"></div>
</div>

The consumer majority is moving fast into digitalization but the marginalised communities that include weavers seem to be disproportionately excluded. It not only increases the great financial inequality but weakens the chances to narrow the gap. There has been an increase in companies focusing on handmade goods in the last decade. This trend was accelerated by the global demand for green consumerism and the massive social media campaign for slow, sustainable products. In the 21st century, green consumption has risen into a global trend, which inclines textile companies to be more environmentally friendly and to have a greener product portfolio to satisfy these new consumers’ needs. Social media contributed to this trend, shaping consumers’ attitudes into more environmentally conscious behaviour. Whether this trend resulted from altruism or egoism is a question that needs answering. It has increased the number of designers coming up with iterations of the existing product line that these weavers have been making for generations, many of whom seem to be running into obscurity within a couple of years. This newfound attention that the handicrafts sector seems to be enjoying hasn't translated to an increase in wages or better working conditions. E-commerce companies market the history and the handmade tag of these crafts. This retro marketing banks on the power of nostalgia linking the customer and the brand on an emotional level by highlighting the usage of traditional handmade equipment by the artisans associated with the brand. This has only further deterred the brands from adapting to newer technology. The labour-intensive, back-breaking work that goes behind the creation of these handloom clothes is not rewarded monetarily. This disparity in wages deters the younger generation from continuing this as a career. The sustainable methods of production practised by these communities need to be updated with the advancement in technology and re-equip them to practise their craft with increased productivity and better quality. There is a need to preserve and document this heritage. It also calls for exploring the possibilities of new methods of production. Artisans and weavers are the third largest segment among the poor in India. Even though the Indian government is implementing initiatives like "Make in India" and "Atmanirbhar Bharat"(Self-reliant India campaign) their dire position receives relatively little attention. Their struggle became even harder with Covid-19, due to the “non-essential” nature of the products they make.

## Design Process

I was inspired by the simplicity of the loom designs of the master woodworking writer Franklin H. Gottshall and intended to design with the minimum possible pieces. A frame loom was reimagined to fit the table considering the size and movements of a laptop. The modularity of design was also a major concern as I intend to add the electronic functionality later on. The initial designs were created for wood with thickness between 8-12 mm and were intended to be cut on a milling machine. Mr. Jogin Francis, my fabacademy instructor at Superfablab, Kerala supported me in this endeavour. A version for 4mm craft Plywood that can be laser cut was made and prototyped in Fablab Barcelona on December 12, 2022. The electronic integration and user interface are developed under the mentorship of Professor Philip Heidkamp, Chair Interface / Interaction Design at Köln International School of Design. The name Indira is synonymous with wealth and is an anagram of the names of my parents.
<p align="center"><img alt="8" src="../../images/week10/8.jpg" /></p>
<p align="center"><img alt="32" src="../../images/week10/32.jpg" /></p>

## Fabrication
<!-- Slider main container -->
<div class="swiper">
<!-- Additional required wrapper -->
<div class="swiper-wrapper">
    <!-- Slides -->
     <div class="swiper-slide">
        <center><img src="../../images/week10/9.jpg" alt="9"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/10.jpg" alt="10"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/11.jpg" alt="11"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/12.jpg" alt="12"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/15.jpg" alt="15"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/16.jpg" alt="16"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/18.jpg" alt="18"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/19.jpg" alt="19"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/20.jpg" alt="20"></center>
    </div>
     <div class="swiper-slide">
        <center><img src="../../images/week10/21.jpg" alt="21"></center>
    </div>
  </div>  
<div class="swiper-pagination"></div>
<div class="swiper-button-prev"></div>
<div class="swiper-button-next"></div>
</div>

## Assembly
<!-- Slider main container -->
<div class="swiper">
<!-- Additional required wrapper -->
<div class="swiper-wrapper">
    <!-- Slides -->
     <div class="swiper-slide">
        <center><img src="../../images/week10/22.jpg" alt="22"></center>
    </div>
     <div class="swiper-slide">
        <center><iframe src="https://player.vimeo.com/video/804581338?h=6fe5d57a7d" width="640" height="564" frameborder="0" allow="autoplay; fullscreen" allowfullscreen></iframe></center>
    </div>
</div>  
<div class="swiper-pagination"></div>
<div class="swiper-button-prev"></div>
<div class="swiper-button-next"></div>
</div>

Here is the final loom ready to be warped. We don't have a warping machine nor yarns to warp. So I was not able to warp and weave it. But hope to do it in the coming days.

<!-- Slider main container -->
<div class="swiper">
<!-- Additional required wrapper -->
<div class="swiper-wrapper">
    <!-- Slides -->
     <div class="swiper-slide">
        <center><img src="../../images/week10/24.jpg" alt="24"></center>
    </div>
     <div class="swiper-slide">
        <center><iframe src="https://player.vimeo.com/video/804581406?h=312b8036ff" width="640" height="564" frameborder="0" allow="autoplay; fullscreen" allowfullscreen></iframe></center>
    </div>
  </div>  
<div class="swiper-pagination"></div>
<div class="swiper-button-prev"></div>
<div class="swiper-button-next"></div>
</div>

## Assembly Manual
I made the assembly manual in a way that it can be printed on any home printer. 
<p align="center"><img alt="26" src="../../images/week10/26.jpg" /></p>

## Bill of Materials

2 sheets of 4mm craft plywood size (900x600mm)

1 sheet of 4mm acrylic size (900x600mm)

5 mtr twine

8 tiny beads


## Outcome
The loom was made by **students** in 2 design colleges in India. 
<br>It  won the **[Design Culture Awards](https://www.archedu.org/designculture2022/)** at Pink city Design confluence, Jaipur under Professional Category. 
<br>The loom was selected by **[Not Just a Collective](https://www.facebook.com/NOTJUSTACOLLECTIVE.Arnhem/)** in Arnhem, Netherlands to be displayed at their collective. <br>The loom will be featured in the **[Distributed Design magazine](https://distributeddesign.eu/)** 2023 edition.

## Files

[Rhino File and Assembly instruction manual](https://gitlab.fabcloud.org/academany/fabricademy/2022/students/nanditha-nair/-/tree/main/docs/files/week10)
